==> featrixclient-2024.530.2.tar.gz: featrixclient-2024.530.2/featrixclient/models/__init__.py <==
#  -*- coding: utf-8 -*-
#############################################################################
#
#  Copyright (c) 2024, Featrix, Inc. All rights reserved.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#
#
#############################################################################
#
#  Yes, you can see this file, but Featrix, Inc. retains all rights.
#
#############################################################################
from .activity import Activity  # noqa F401
from .api_key import ApiKey  # noqa F401
from .api_key import ApiKeyAuthenticationRequest  # noqa F401
from .api_key import ApiKeyAuthResponse  # noqa F401
from .api_key import ApiKeyCreated  # noqa F401
from .api_key import ApiKeyCreateRequest  # noqa F401
from .api_key import ApiKeyEntry  # noqa F401
from .api_key import KEYFILE_LOCATION  # noqa F401
from .association import UploadAssociation  # noqa F401
from .embedding_space import EmbeddingDistanceRequest  # noqa F401
from .embedding_space import EmbeddingDistanceResponse  # noqa F401
from .embedding_space import EmbeddingSpace  # noqa F401
from .embedding_space import EmbeddingSpaceCheckGuardrailsRequest  # noqa F401
from .embedding_space import EmbeddingSpaceCheckGuardrailsResponse  # noqa F401
from .embedding_space import EmbeddingSpaceCreateRequest  # noqa F401
from .embedding_space import EmbeddingSpaceCreateResponse  # noqa F401
from .embedding_space import EmbeddingSpaceDatabaseCreateRequest  # noqa F401
from .embedding_space import EmbeddingSpaceDatabaseCreateResponse  # noqa F401
from .embedding_space import EmbeddingSpaceDatabaseStatusResponse  # noqa F401
from .embedding_space import EmbeddingSpaceDeleteRequest  # noqa F401
from .embedding_space import EmbeddingSpaceDeleteResponse  # noqa F401
from .embedding_space import EmbeddingSpaceEncodeRequest  # noqa F401
from .embedding_space import EmbeddingSpaceEncodeResponse  # noqa F401
from .embedding_space import EmbeddingSpaceNearestNeighborRequest  # noqa F401
from .embedding_space import EmbeddingSpaceNearestNeighborResponse  # noqa F401
from .embedding_space import EmbeddingSpaceTrainModelRequest  # noqa F401
from .embedding_space import EmbeddingSpaceTrainModelResponse  # noqa F401
from .embedding_space import EmbeddingSpaceValueHistogramRequest  # noqa F401
from .embedding_space import EmbeddingSpaceValueHistogramResponse  # noqa F401
from .embedding_space import TrainingInfo  # noqa F401
from .featrix_base import FeatrixBase  # noqa F401
from .feed import Feed  # noqa F401
from .feed import FeedCreateArgs  # noqa F401
from .feed import FeedWithEventCounts  # noqa F401
from .fmodel import FModel  # noqa F401
from .invitation import Invitation  # noqa F401
from .invitation import InviteUserRequest  # noqa F401
from .job_dispatching import JobResults  # noqa F401
from .job_meta import JobDispatch  # noqa F401
from .job_meta import JobIncrementalStatus  # noqa F401
from .job_meta import JobInfoResponse  # noqa F401
from .job_meta import JobMeta  # noqa F401
from .job_meta import JobStatus  # noqa F401
from .job_meta import Loss  # noqa F401
from .job_requests import AutoJoinDetectArgs  # noqa F401
from .job_requests import AutoJoinProjectionArgs  # noqa F401
from .job_requests import CreateDBArgs  # noqa F401
from .job_requests import CreateFromDSArgs  # noqa F401
from .job_requests import DBClusterArgs  # noqa F401
from .job_requests import EmbeddingsDistanceArgs  # noqa F401
from .job_requests import EncodeRecordsArgs  # noqa F401
from .job_requests import Encoders  # noqa F401
from .job_requests import ESCreateArgs  # noqa F401
from .job_requests import ESWaitToFinish  # noqa F401
from .job_requests import GuardRailsArgs  # noqa F401
from .job_requests import JobArgs  # noqa F401
from .job_requests import ModelCreateArgs  # noqa F401
from .job_requests import ModelFastPredictionArgs  # noqa F401
from .job_requests import ModelPredictionArgs  # noqa F401
from .job_requests import NewNeuralFunctionArgs  # noqa F401
from .job_requests import NewExplorerArgs  # noqa F401
from .job_requests import NNQueryArgs  # noqa F401
from .job_requests import ProcessSmartEnrichmentArgs  # noqa F401
from .job_requests import ProcessUploadArgs  # noqa F401
from .job_requests import TestCaseArgs  # noqa F401
from .job_requests import TrainMoreArgs  # noqa F401
from .job_type import ChainedJobType  # noqa F401
from .job_type import JobType  # noqa F401
from .job_usage import CPUInfo  # noqa F401
from .job_usage import DiskInfo  # noqa F401
from .job_usage import DiskOverview  # noqa F401
from .job_usage import JobUsageStats  # noqa F401
from .job_usage import LoadStats  # noqa F401
from .job_usage import MemoryInfo  # noqa F401
from .job_usage import PartitionDetail  # noqa F401
from .job_usage import PartitionInfo  # noqa F401
from .job_usage import PartitionUsage  # noqa F401
from .job_usage import PlatformInfo  # noqa F401
from .job_usage import ProcessStats  # noqa F401
from .model import Model  # noqa F401
from .organization import Features  # noqa F401
from .organization import Organization  # noqa F401
from .organization import UpdatedRequest  # noqa F401
from .organization import UpdatedResponse  # noqa F401
from .prediction import Prediction  # noqa F401
from .project import AllFieldsResponse  # noqa F401
from .project import ProjectType  # noqa F401
from .project import Project  # noqa F401
from .project import ProjectAddMappingsRequest  # noqa F401
from .project import ProjectAssociateRequest  # noqa F401
from .project import ProjectAutoJoinRequest  # noqa F401
from .project import ProjectCreateParameters  # noqa F401
from .project import ProjectCreateRequest  # noqa F401
from .project import ProjectDeleteResponse  # noqa F401
from .project import ProjectEditRequest  # noqa F401
from .project import ProjectFocusColsRequest  # noqa F401
from .project import ProjectIgnoreColsRequest  # noqa F401
from .project import ProjectRowMetaData  # noqa F401
from .project import ProjectSearchMappingsRequest  # noqa F401
from .project import ProjectTableMapping  # noqa F401
from .project import ProjectTag  # noqa F401
from .project import ProjectUnassociateRequest  # noqa F401
from .project import UploadAssociation  # noqa F401
from .pydantic_objectid import PydanticObjectId  # noqa F401
from .training import TrainingState  # noqa F401
from .upload import Upload  # noqa F401
from .upload import UploadConfigureArgs  # noqa F401
from .upload import UploadFetchUrlArgs  # noqa F401
from .upload import UploadFileResponse  # noqa F401
from .upload import UploadSmartEnrichmentConfigureArgs  # noqa F401
from .user import User  # noqa F401
from .user import UserBrief  # noqa F401

==> featrixclient-2024.904.6.tar.gz: featrixclient-2024.904.6/featrixclient/models/__init__.py <==
#  -*- coding: utf-8 -*-
#############################################################################
#
#  Copyright (c) 2024, Featrix, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#############################################################################
#
#     Welcome to...
#
#      _______ _______ _______ _______ ______ _______ ___ ___
#     |    ___|    ___|   _   |_     _|   __ \_     _|   |   |
#     |    ___|    ___|       | |   | |      <_|   |_|-     -|
#     |___|   |_______|___|___| |___| |___|__|_______|___|___|
#
#                                                 Let's embed!
#
#############################################################################
#
#  Sign up for Featrix at https://app.featrix.com/
# 
#############################################################################
#
#  Check out the docs -- you can either call the python built-in help()
#  or fire up your browser:
#
#     https://featrix-docs.readthedocs.io/en/latest/
#
#  You can also join our community Slack:
#
#     https://bits.featrix.com/slack
#
#  We'd love to hear from you: bugs, features, questions -- send them along!
#
#     hello@featrix.ai
#
#############################################################################
#
# from .activity import Activity  # noqa F401
# from .api_key import ApiKey  # noqa F401
# from .api_key import ApiKeyAuthenticationRequest  # noqa F401
# from .api_key import ApiKeyAuthResponse  # noqa F401
# from .api_key import ApiKeyCreated  # noqa F401
# from .api_key import ApiKeyCreateRequest  # noqa F401
# from .api_key import ApiKeyEntry  # noqa F401
# from .api_key import KEYFILE_LOCATION  # noqa F401
from .association import UploadAssociation  # noqa F401
from .embedding_space import EmbeddingDistanceRequest  # noqa F401
from .embedding_space import EmbeddingDistanceResponse  # noqa F401
from .embedding_space import EmbeddingSpace  # noqa F401
from .embedding_space import EmbeddingSpaceCheckGuardrailsRequest  # noqa F401
from .embedding_space import EmbeddingSpaceCheckGuardrailsResponse  # noqa F401
from .embedding_space import EmbeddingSpaceCreateRequest  # noqa F401
from .embedding_space import EmbeddingSpaceCreateResponse  # noqa F401
from .embedding_space import EmbeddingSpaceDeleteRequest  # noqa F401
from .embedding_space import EmbeddingSpaceDeleteResponse  # noqa F401
from .embedding_space import EmbeddingSpaceEncodeRequest  # noqa F401
from .embedding_space import EmbeddingSpaceEncodeResponse  # noqa F401
from .embedding_space import EmbeddingSpaceTrainModelRequest  # noqa F401
from .embedding_space import EmbeddingSpaceTrainModelResponse  # noqa F401
from .embedding_space import EmbeddingSpaceValueHistogramRequest  # noqa F401
from .embedding_space import EmbeddingSpaceValueHistogramResponse  # noqa F401
from .embedding_space import TrainingInfo  # noqa F401
from .featrix_base import FeatrixBase  # noqa F401
from .feed import Feed  # noqa F401
from .feed import FeedCreateArgs  # noqa F401
from .feed import FeedWithEventCounts  # noqa F401
from .fmodel import FModel  # noqa F401
from .job_dispatching import JobResults  # noqa F401
from .job_meta import JobDispatch  # noqa F401
from .job_meta import JobIncrementalStatus  # noqa F401
from .job_meta import JobInfoResponse  # noqa F401
from .job_meta import JobMeta  # noqa F401
from .job_meta import JobStatus  # noqa F401
from .job_meta import Loss  # noqa F401
from .job_requests import EncodeRecordsArgs  # noqa F401
from .job_requests import Encoders  # noqa F401
from .job_requests import ESCreateArgs  # noqa F401
from .job_requests import ESWaitToFinish  # noqa F401
from .job_requests import GuardRailsArgs  # noqa F401
from .job_requests import JobArgs  # noqa F401
from .job_requests import ModelCreateArgs  # noqa F401
from .job_requests import ModelFastPredictionArgs  # noqa F401
from .job_requests import ModelPredictionArgs  # noqa F401
from .job_requests import ProcessSmartEnrichmentArgs  # noqa F401
from .job_requests import ProcessUploadArgs  # noqa F401
from .job_requests import TestCaseArgs  # noqa F401
from .job_requests import TrainMoreArgs  # noqa F401
from .job_type import JobType  # noqa F401
from .model import Model  # noqa F401
from .organization import Features  # noqa F401
from .organization import Organization  # noqa F401
from .organization import UpdatedRequest  # noqa F401
from .organization import UpdatedResponse  # noqa F401
from .prediction import Prediction  # noqa F401
from .project import AllFieldsResponse  # noqa F401
from .project import Project  # noqa F401
from .project import ProjectAddMappingsRequest  # noqa F401
from .project import ProjectAssociateRequest  # noqa F401
from .project import ProjectAutoJoinRequest  # noqa F401
from .project import ProjectCreateParameters  # noqa F401
from .project import ProjectCreateRequest  # noqa F401
from .project import ProjectDeleteResponse  # noqa F401
from .project import ProjectEditRequest  # noqa F401
from .project import ProjectFocusColsRequest  # noqa F401
from .project import ProjectIgnoreColsRequest  # noqa F401
from .project import ProjectRowMetaData  # noqa F401
from .project import ProjectSearchMappingsRequest  # noqa F401
from .project import ProjectTableMapping  # noqa F401
from .project import ProjectTag  # noqa F401
from .project import ProjectType  # noqa F401
from .project import ProjectUnassociateRequest  # noqa F401
from .project import UploadAssociation  # noqa F401
from .pydantic_objectid import PydanticObjectId  # noqa F401
from .training import TrainingState  # noqa F401
from .upload import Upload  # noqa F401
from .upload import UploadConfigureArgs  # noqa F401
from .upload import UploadFetchUrlArgs  # noqa F401
from .upload import UploadFileResponse  # noqa F401
from .upload import UploadSmartEnrichmentConfigureArgs  # noqa F401
from .user import User  # noqa F401
# from .job_requests import AutoJoinDetectArgs  # noqa F401
# from .job_requests import AutoJoinProjectionArgs  # noqa F401
# from .job_requests import CreateDBArgs  # noqa F401
# from .job_requests import CreateFromDSArgs  # noqa F401
# from .job_requests import DBClusterArgs  # noqa F401
# from .job_requests import EmbeddingsDistanceArgs  # noqa F401
# from .job_requests import NewNeuralFunctionArgs  # noqa F401
# from .job_requests import NewExplorerArgs  # noqa F401
# from .job_requests import NNQueryArgs  # noqa F401
# from .job_type import ChainedJobType  # noqa F401
# from .job_usage import CPUInfo  # noqa F401
# from .job_usage import DiskInfo  # noqa F401
# from .job_usage import DiskOverview  # noqa F401
# from .job_usage import JobUsageStats  # noqa F401
# from .job_usage import LoadStats  # noqa F401
# from .job_usage import MemoryInfo  # noqa F401
# from .job_usage import PartitionDetail  # noqa F401
# from .job_usage import PartitionInfo  # noqa F401
# from .job_usage import PartitionUsage  # noqa F401
# from .job_usage import PlatformInfo  # noqa F401
# from .job_usage import ProcessStats  # noqa F401
# from .user import UserBrief  # noqa F401
